# frozen_string_literal: true

# app/hermes/models/concerns/status.rb
# app/controllers/concerns/test_concern.rb

module Hermes
  module Concerns
    # Handles statuses relationships
    module EligibilityConcern
      extend ActiveSupport::Concern

      included do
        field :eligibility_query_base, type: String
        field :eligibility_query_department, type: String
        field :eligibility_query_seeked, type: String
        field :eligibility_query_bordering, type: String
        field :eligibility_query_seeked_bordering, type: String
        field :eligibility_query_other_from_department, type: String

        def self.eligibility_types
          %w[
            department
            seeked
            bordering
            seeked_bordering
            other_from_department
          ]
        end 

        def blank_or_missing(value)
          value.blank? ? "missing value" : value
        end 

        def array_blank_or_missing(value)
          value.blank? ? ["missing value"] : value
        end 

        def calculate_eligibility_base
          raise "calculate_eligibility_base not implemented"
        end 

        def calculate_eligibility_by_type
          raise "calculate_eligibility_by_type not implemented"
        end 

        def update_eligibility_query
          self.eligibility_query_base = calculate_eligibility_base.to_json
          self.class.eligibility_types.each do |type|
            self.assign_attributes("eligibility_query_#{type}": calculate_eligibility_by_type(type).to_json)
          end
        end
      
        def eligibility_query(type = 'department')
          query = JSON.parse(eligibility_query_base, symbolize_names: true)
          query_type = JSON.parse(self["eligibility_query_#{type}"], symbolize_names: true)
          query.merge(query_type)
        end 

      end
    end
  end
end
